@@ -1,25 +1,22 @@
-import os
 import argparse
-import time
-import signal
-
-import multiprocessing
-import threading
-
-from typing import Union, Dict, Optional, TYPE_CHECKING
 import asyncio
+import multiprocessing
+import os
+import signal
+import threading
+import time
+from typing import TYPE_CHECKING, Dict, Optional, Union
 
-from jina import __windows__
+from jina import __docker_host__, __windows__
+from jina.helper import random_name, slugify
 from jina.importer import ImportExtensions
-from jina.orchestrate.pods import BasePod
-from jina.orchestrate.pods import _get_worker
-from jina.orchestrate.pods.container_helper import (
-    get_gpu_device_requests,
-    get_docker_network,
-)
-from jina import __docker_host__
 from jina.logging.logger import JinaLogger
-from jina.helper import slugify, random_name
+from jina.orchestrate.helper import generate_default_volume_and_workspace
+from jina.orchestrate.pods import BasePod
+from jina.orchestrate.pods.container_helper import (
+    get_docker_network,
+    get_gpu_device_requests,
+)
 from jina.serve.runtimes.asyncio import AsyncNewLoopRuntime
 
 if TYPE_CHECKING:
@@ -36,8 +33,10 @@ def _docker_run(
 ):
     # important to notice, that client is not assigned as instance member to avoid potential
     # heavy copy into new process memory space
-    import docker
     import warnings
+
+    import docker
+
     from jina.excepts import BadImageNameError, DockerVersionError
 
     docker_version = client.version().get('Version')
@@ -65,10 +64,11 @@ def _docker_run(
     # the image arg should be ignored otherwise it keeps using ContainerPod in the container
     # basically all args in Pod-docker arg group should be ignored.
     # this prevent setting containerPod twice
-    from jina.parsers import set_pod_parser
-    from jina.helper import ArgNamespace
     from pathlib import Path
 
+    from jina.helper import ArgNamespace
+    from jina.parsers import set_pod_parser
+
     args.native = True
 
     non_defaults = ArgNamespace.get_non_defaults_args(
@@ -108,6 +108,16 @@ def _docker_run(
         raise BadImageNameError(f'image: {uses_img} can not be found local & remote.')
 
     _volumes = {}
+    if not args.disable_auto_volume and not args.volumes:
+        (
+            generated_volumes,
+            workspace_in_container,
+        ) = generate_default_volume_and_workspace(workspace_id=args.workspace_id)
+        args.volumes = generated_volumes
+        args.workspace = (
+            workspace_in_container if not args.workspace else args.workspace
+        )
+
     if args.volumes:
         for p in args.volumes:
             paths = p.split(':')
@@ -128,7 +138,7 @@ def _docker_run(
         del args.gpus
 
     _args = ArgNamespace.kwargs2list(non_defaults)
-    ports = {f'{args.port_in}/tcp': args.port_in} if not net_mode else None
+    ports = {f'{args.port}/tcp': args.port} if not net_mode else None
 
     docker_kwargs = args.docker_kwargs or {}
     container = client.containers.run(
@@ -290,7 +300,6 @@ class ContainerPod(BasePod):
             self.args.docker_kwargs.pop('extra_hosts')
         self._net_mode = None
         self.worker = None
-        self.daemon = self.args.daemon  #: required here to set process/thread daemon
         self.container_name = slugify(f'{self.name}/{random_name()}')
         self.net_mode, self.runtime_ctrl_address = self._get_control_address()
 
@@ -318,7 +327,7 @@ class ContainerPod(BasePod):
             else:
                 ctrl_host = self.args.host
 
-            ctrl_address = f'{ctrl_host}:{self.args.port_in}'
+            ctrl_address = f'{ctrl_host}:{self.args.port}'
 
             net_node, runtime_ctrl_address = self._get_network_for_dind_linux(
                 client, ctrl_address
@@ -334,7 +343,6 @@ class ContainerPod(BasePod):
 
         # Related to potential docker-in-docker communication. If `Runtime` lives already inside a container.
         # it will need to communicate using the `bridge` network.
-
         # In WSL, we need to set ports explicitly
         net_mode, runtime_ctrl_address = None, ctrl_address
         if sys.platform in ('linux', 'linux2') and 'microsoft' not in uname().release:
@@ -342,7 +350,7 @@ class ContainerPod(BasePod):
             try:
                 bridge_network = client.networks.get('bridge')
                 if bridge_network:
-                    runtime_ctrl_address = f'{bridge_network.attrs["IPAM"]["Config"][0]["Gateway"]}:{self.args.port_in}'
+                    runtime_ctrl_address = f'{bridge_network.attrs["IPAM"]["Config"][0]["Gateway"]}:{self.args.port}'
             except Exception as ex:
                 self.logger.warning(
                     f'Unable to set control address from "bridge" network: {ex!r}'
@@ -368,8 +376,7 @@ class ContainerPod(BasePod):
         This method calls :meth:`start` in :class:`threading.Thread` or :class:`multiprocesssing.Process`.
         .. #noqa: DAR201
         """
-        self.worker = _get_worker(
-            args=self.args,
+        self.worker = multiprocessing.Process(
             target=run,
             kwargs={
                 'args': self.args,
@@ -382,6 +389,7 @@ class ContainerPod(BasePod):
                 'is_shutdown': self.is_shutdown,
                 'is_ready': self.is_ready,
             },
+            daemon=True,
         )
         self.worker.start()
         if not self.args.noblock_on_start:
@@ -397,14 +405,9 @@ class ContainerPod(BasePod):
             self._container.kill(signal='SIGTERM')
         finally:
             self.is_shutdown.wait(self.args.timeout_ctrl)
-            if hasattr(self.worker, 'terminate'):
-                self.logger.debug(f'terminating the runtime process')
-                self.worker.terminate()
-                self.logger.debug(f' runtime process properly terminated')
-            else:
-                self.logger.debug(f'canceling the runtime thread')
-                self.cancel_event.set()
-                self.logger.debug(f'runtime thread properly canceled')
+            self.logger.debug(f'terminating the runtime process')
+            self.worker.terminate()
+            self.logger.debug(f' runtime process properly terminated')
 
     def join(self, *args, **kwargs):
         """Joins the Pod.
