@@ -1,12 +1,7 @@
 """Argparser module for remote runtime"""
-from argparse import _StoreTrueAction
 
 from jina import __default_host__, helper
-from jina.parsers.helper import (
-    KVAppendAction,
-    add_arg_group,
-    get_deprecation_renamed_action,
-)
+from jina.parsers.helper import KVAppendAction, add_arg_group
 
 
 def mixin_remote_runtime_parser(parser):
@@ -16,13 +11,6 @@ def mixin_remote_runtime_parser(parser):
     gp = add_arg_group(parser, title='RemoteRuntime')
     _add_host(gp)
 
-    gp.add_argument(
-        '--port-jinad',
-        type=int,
-        default=8000,
-        help='The port of the remote machine for usage with JinaD.',
-    )
-
 
 def mixin_client_gateway_parser(parser):
     """Add the options for the client connecting to the Gateway
@@ -46,15 +34,6 @@ def mixin_client_gateway_parser(parser):
         help='If set, connect to gateway using tls encryption',
     )
 
-    gp.add_argument(
-        '--https',
-        action=get_deprecation_renamed_action('--tls', _StoreTrueAction),
-        # action='store_true',
-        default=False,
-        help='If set, connect to gateway using https',
-        dest='tls',
-    )
-
 
 def mixin_gateway_parser(parser):
     """Add the options for remote expose at the Gateway
@@ -93,6 +72,13 @@ def mixin_gateway_parser(parser):
         default='{}',
     )
 
+    parser.add_argument(
+        '--deployments-disable-reduce',
+        type=str,
+        help='list JSON disabling the built-in merging mechanism for each Deployment listed',
+        default='[]',
+    )
+
     gp.add_argument(
         '--compression',
         type=str,
@@ -212,6 +198,34 @@ More details can be found in Uvicorn docs: https://www.uvicorn.org/settings/
 ''',
     )
 
+    gp.add_argument(
+        '--grpc-server-kwargs',
+        action=KVAppendAction,
+        metavar='KEY: VALUE',
+        nargs='*',
+        help='''
+    Dictionary of kwargs arguments that will be passed to the grpc server when starting the server # todo update
+    ''',
+    )
+
+    gp.add_argument(
+        '--ssl-certfile',
+        type=str,
+        help='''
+        the path to the certificate file
+        ''',
+        dest='ssl_certfile',
+    )
+
+    gp.add_argument(
+        '--ssl-keyfile',
+        type=str,
+        help='''
+        the path to the key file
+        ''',
+        dest='ssl_keyfile',
+    )
+
 
 def mixin_prefetch_parser(parser=None):
     """Add the options for prefetching
