@@ -16,7 +16,10 @@ class GatewayRuntime(AsyncNewLoopRuntime, ABC):
 
         graph_description = json.loads(self.args.graph_description)
         graph_conditions = json.loads(self.args.graph_conditions)
-        self._topology_graph = TopologyGraph(graph_description, graph_conditions)
+        deployments_disable_reduce = json.loads(self.args.deployments_disable_reduce)
+        self._topology_graph = TopologyGraph(
+            graph_description, graph_conditions, deployments_disable_reduce
+        )
 
     def _set_connection_pool(self):
         import json
@@ -24,7 +27,9 @@ class GatewayRuntime(AsyncNewLoopRuntime, ABC):
         deployments_addresses = json.loads(self.args.deployments_addresses)
         # add the connections needed
         self._connection_pool = GrpcConnectionPool(
-            logger=self.logger, compression=self.args.compression
+            logger=self.logger,
+            compression=self.args.compression,
+            metrics_registry=self.metrics_registry,
         )
         for deployment_name, addresses in deployments_addresses.items():
             for address in addresses:
