@@ -10,17 +10,26 @@ from jina.types.request.data import DataRequest
 if TYPE_CHECKING:
     import argparse
 
+    from prometheus_client import CollectorRegistry
+
     from jina.logging.logger import JinaLogger
 
 
 class DataRequestHandler:
     """Object to encapsulate the code related to handle the data requests passing to executor and its returned values"""
 
-    def __init__(self, args: 'argparse.Namespace', logger: 'JinaLogger', **kwargs):
+    def __init__(
+        self,
+        args: 'argparse.Namespace',
+        logger: 'JinaLogger',
+        metrics_registry: Optional['CollectorRegistry'] = None,
+        **kwargs,
+    ):
         """Initialize private parameters and execute private loading functions.
 
         :param args: args from CLI
         :param logger: the logger provided by the user
+        :param metrics_registry: optional metrics registry for prometheus used if we need to expose metrics from the executor of from the data request handler
         :param kwargs: extra keyword arguments
         """
         super().__init__()
@@ -28,26 +37,31 @@ class DataRequestHandler:
         self.args.parallel = self.args.shards
         self.logger = logger
         self._is_closed = False
-        self._load_executor()
+        self._load_executor(metrics_registry)
 
-    def _load_executor(self):
-        """Load the executor to this runtime, specified by ``uses`` CLI argument."""
+    def _load_executor(self, metrics_registry: Optional['CollectorRegistry'] = None):
+        """
+        Load the executor to this runtime, specified by ``uses`` CLI argument.
+        :param metrics_registry: Optional prometheus metrics registry that will be passed to the executor so that it can expose metrics
+        """
         try:
             self._executor: BaseExecutor = BaseExecutor.load_config(
                 self.args.uses,
                 uses_with=self.args.uses_with,
                 uses_metas=self.args.uses_metas,
                 uses_requests=self.args.uses_requests,
-                runtime_args={
+                runtime_args={  # these are not parsed to the yaml config file but are pass directly during init
                     'workspace': self.args.workspace,
                     'shard_id': self.args.shard_id,
                     'shards': self.args.shards,
                     'replicas': self.args.replicas,
                     'name': self.args.name,
-                    'py_modules': self.args.py_modules,
+                    'metrics_registry': metrics_registry,
                 },
+                py_modules=self.args.py_modules,
                 extra_search_paths=self.args.extra_search_paths,
             )
+
         except BadConfigSource as ex:
             self.logger.error(
                 f'fail to load config from {self.args.uses}, if you are using docker image for --uses, '
@@ -162,7 +176,7 @@ class DataRequestHandler:
                     existing_executor_routes.append(route.executor)
 
     def close(self):
-        """ Close the data request handler, by closing the executor """
+        """Close the data request handler, by closing the executor"""
         if not self._is_closed:
             self._executor.close()
             self._is_closed = True
